<?php

namespace Drupal\custom_db_table_views\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines the configuration export form.
 */
class DBTableExportForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'config_customtable_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'custom_db_table_views.settings',
    ];
  }
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form = parent::buildForm($form, $form_state);
    $config = $this->config('custom_db_table_views.settings');
    $form['db_table_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Table Name'),
      '#required' => true,
      '#default_value' => $config->get('db_table_name'),
    ];
    $form['db_views_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Views Name'),
      '#required' => true,
      '#default_value' => $config->get('db_views_name'),
    ];
    return $form;

  }

/**
  * {@inheritdoc}
  */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('custom_db_table_views.settings');
    $config->set('db_table_name', $form_state->getValue('db_table_name'));
    $config->set('db_views_name', $form_state->getValue('db_views_name'));
    $config->save();

  return parent::submitForm($form, $form_state);
  }
  
/**
 * {@inheritdoc}
 */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $table_existance = db_table_exists($form_state->getValue('db_table_name'));
    if ($table_existance == false) {
      $form_state->setErrorByName('db_table_name', $this->t('Please enter a valid existing table name.'));
    }
  }

}

